** Jeffrey Clemens 5.11.2017
** Desciption: Clean and Analyze CPS Data for "The Minimum Wage and the Great 
** Recession: A Response to Zipperer and Recapitulation of the Evidence"

** Notes: Running this file requires the following data sets:
** 1) An extract of the Current Population Survey (CPS) for years 2006 through 
** 2012 from the Minnesota Population Center’s Integrated Public Use Microsamples   
** Project.  The data set must contain the CPS variables referenced in the code below.
** 2) Macro_Controls.dta
** The file Macro_Controls.dta is available either through the replication packet in 
** which you have obtained this .do file or, as needed, from Jeffrey Clemens. 
** The file contains an FHFA median house price index which, as of 5/11/2017,
** could be downloaded directly from:
** https://www.fhfa.gov/DataTools/Downloads/Documents/HPI/HPI_AT_state.csv
** Note that the median house price index is the only variable from Macro_Controls.dta
** that is required to estimate the "baseline" specification.  Additional control
** variables in Macro_Controls.dta include standard state level data on the employment
** rate, the unemployment rate, and personal income per capita.  The employment
** series are available through the Bureau of Labor Statistics and the personal
** income series is available through the Bureau of Economic Analysis.
** 3) ConstructionBEAForMerge.dta
** This data set contains construction output data from the Bureau of Economic
** Analysis. Like Macro_Controls.dta, it is available either through the replication 
** packet in which you have obtained this .do file or, as needed, from Jeffrey Clemens.
** 4) MinimumWageRatesByStateAndMonth
** This is a modestly revised version of the minimum wage panel from the replication
** materials associated with "Effects of the Minimum Wage on Employment Dynamics" by
** Jonathan Meer and Jeremy West (JHR, 2016).  Note that only states' January 2008
** minimum wage rates are needed to replicate our "baseline" specification.
** These minimum wage rates can, as of 5/11/2017, be found at the following link 
** from the Bureau of Labor Statistics: https://www.dol.gov/whd/state/stateMinWageHis.htm

clear
capture log close 

set matsize 5000

* Set up directory structure
global sippdatadirectory C:\Users\cleme\Dropbox\Min Wage\Raw_SIPP_Data\sipp\2008
global cpsdatadirectory C:\Users\cleme\Dropbox\Min Wage\Data\CPS
global workdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive
global logdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive
global additionaldatadirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive
global resultsdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\WithinRegionCritiqueReplicationArchive\Results

cd "${workdirectory}"

capture log close
log using "${logdirectory}/WithinRegionCritique_CPSAnalysis.log", replace


*=======================================================================
***** Code for cleaning CPS data and merging in supplementary data sets
*=======================================================================
**** Bring in CPS
use "${cpsdatadirectory}\CPSemployment2002to2015.dta", clear
capture drop serial hwtfinl hwtsupp cpsid asecflag pernum wtsupp 
drop if year < 2006 | year > 2012
*** Drop seniors and kids
capture drop if age >= 65 | age < 16


*** Merge in 05-06 industry share variables
merge m:1 statefip using "${additionaldatadirectory}/QCEW0506indshares.dta"
keep if _merge == 3
drop _merge

*** Merge in House Price Index Match Variables
merge m:1 statefip using "${additionaldatadirectory}/IndexDeclineMatchVariables.dta"
keep if _merge == 3 
drop _merge

*** Merge in additional macroeconomic control variables
merge m:1 statefip year month using "${additionaldatadirectory}/Macro_Controls.dta"
keep if _merge == 3
drop _merge
drop index_nsa index_sa index_at civilian_pop cpi CPI

foreach var in index personal_income {
replace `var' = `var'/1000
}

foreach var in employment_rate {
replace `var' = `var'/100
}

gen quarter = 1
replace quarter = 2 if month >= 4 & month <= 6
replace quarter = 3 if month >= 7 & month <= 9
replace quarter = 4 if month >= 10 & month <= 12
merge m:1 statefip year quarter using "${additionaldatadirectory}/ConstructionBEAForMerge.dta"
keep if _merge != 2 
drop _merge


*** Merge in data on minimum wage rates
merge m:1 statefip year month using "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta"
keep if _merge == 3 
drop _merge

merge m:1 statefip using "${additionaldatadirectory}/Jan2008MWs.dta"
keep if _merge == 3 
drop _merge


*** Construct treatment and treatment x post indicators
gen Treatment = mw2008<6.55

gen time = 100*year+month
gen Post = time>=200908
gen Post1 = time>=200908 & time<=201007
gen Post2 = time>=201008
gen Transition = time>=200705 & time<=200907

gen Treatment_Post = Treatment*Post
gen Treatment_Post_1 = Treatment*Post1
gen Treatment_Post_2 = Treatment*Post2
gen Treatment_Trans = Treatment*Transition

gen period = 0
replace  period = 1 if Transition == 1
replace  period = 2 if Post1 == 1
replace  period = 3 if Post2 == 1

gen SIPPPre = time < 200905 & time>=200807


**** Construct education variables
gen continuouseducA = .
replace continuouseducA = 1 if educ < 73
replace continuouseducA = 2 if educ == 73
replace continuouseducA = 3 if educ >= 81 & educ != .
label define continuouseducA 1 "Dropout" 2 "High School" 3 "Some College Plus"

**** Construct age grouping variables
gen agegroupA = .
replace agegroupA =1 if age <= 30
replace agegroupA =2 if age > 30 & age <= 45
replace agegroupA =3 if age > 45 & age < 65
label define agegroupA 1 "Under 30" 2 "30 to 40" 3 "Over 45"

gen agegroupB = .
replace agegroupB =1 if age <= 21
replace agegroupB =2 if age > 21 & age <= 45
replace agegroupB =3 if age > 45 & age <= 65

*** Construct economic outcomes of interest
gen employed = 0
replace employed = 1 if  empstat == 1 | empstat == 10 | empstat == 12

*** Constructing sampling time frame variables
gen sampleframeE = 0
replace sampleframeE = 1 if time > 200600 & time <= 201300

*** Generate skill group variable 
gen skillgroup = 3
replace skillgroup = 1 if continuouseducA == 1 & agegroupA == 1
replace skillgroup = 2 if (continuouseducA != 1 & agegroupA == 1) | (continuouseducA == 1 & agegroupA == 2)


*** Construct census region and census division variables
gen region = 0
replace region = 1 if statefip == 9 | statefip == 23 | statefip == 25 | statefip == 33 | statefip == 44 | statefip == 50
replace region = 1 if statefip == 34 | statefip == 36 | statefip == 42
replace region = 2 if statefip == 17 | statefip == 18 | statefip == 26 | statefip == 39 | statefip == 55 
replace region = 2 if statefip == 19 | statefip == 20 | statefip == 27 | statefip == 29 | statefip == 31 | statefip == 38 | statefip == 46
replace region = 3 if statefip == 10 | statefip == 11 | statefip == 12 | statefip == 13 | statefip == 24 | statefip == 37 | statefip == 45 | statefip == 51 | statefip == 54
replace region = 3 if statefip == 1 | statefip == 21 | statefip == 28 | statefip == 47
replace region = 3 if statefip == 5 | statefip == 22 | statefip == 40 | statefip == 48
replace region = 4 if statefip == 4 | statefip == 8 | statefip == 16 | statefip == 30 | statefip == 32 | statefip == 35 | statefip == 49 | statefip == 56
replace region = 4 if statefip == 2 | statefip == 6 | statefip == 15 | statefip == 41 | statefip == 53

gen regionstring = ""
replace regionstring = "Northeast" if region == 1
replace regionstring = "Midwest" if region == 2
replace regionstring = "South" if region == 3
replace regionstring = "West" if region == 4

gen division = 0
replace division = 1 if statefip == 9 | statefip == 23 | statefip == 25 | statefip == 33 | statefip == 44 | statefip == 50
replace division = 2 if statefip == 34 | statefip == 36 | statefip == 42
replace division = 3 if statefip == 17 | statefip == 18 | statefip == 26 | statefip == 39 | statefip == 55 
replace division = 4 if statefip == 19 | statefip == 20 | statefip == 27 | statefip == 29 | statefip == 31 | statefip == 38 | statefip == 46
replace division = 5 if statefip == 10 | statefip == 11 | statefip == 12 | statefip == 13 | statefip == 24 | statefip == 37 | statefip == 45 | statefip == 51 | statefip == 54
replace division = 6 if statefip == 1 | statefip == 21 | statefip == 28 | statefip == 47
replace division = 7 if statefip == 5 | statefip == 22 | statefip == 40 | statefip == 48
replace division = 8 if statefip == 4 | statefip == 8 | statefip == 16 | statefip == 30 | statefip == 32 | statefip == 35 | statefip == 49 | statefip == 56
replace division = 9 if statefip == 2 | statefip == 6 | statefip == 15 | statefip == 41 | statefip == 53



*==================================================
***** Code for summary statistics tables 
*==================================================
**** Prepare variables for summary statistics tables
label var personal_income "Income Per Cap. (1000s)"
label var employment_rate "Employment Rate"
label var unemployment_rate "Unemployment Rate"
label var index "Med. House Price (Millions)"
label var construction "Const. Output Index (BEA)"

gen PeriodCPS = ""
replace PeriodCPS = "base" if period == 0
replace PeriodCPS = "post" if period == 2 | period == 3
egen employedprime = wtmean(employed) if age >= 25 & age <= 54, by(statefip PeriodCPS) weight(wtfinl)
egen employedyoung = wtmean(employed) if age >= 16 & age <= 21, by(statefip PeriodCPS) weight(wtfinl)
egen employedlow = wtmean(employed) if continuouseducA == 1 & age <= 30 , by(statefip PeriodCPS) weight(wtfinl)
gen constructionind = ind1990 == 60
gen constructionemp =  constructionind == 1 & employed == 1
egen constructionemployed = wtmean(constructionemp) if age >= 16 & age <= 64 , by(statefip PeriodCPS) weight(wtfinl)

gen PeriodSIPP = ""
replace PeriodSIPP = "base" if time >= 200807 & time <= 200904
replace PeriodSIPP = "post" if period == 2 | period == 3
egen employedprimeSIPP = wtmean(employed) if age >= 25 & age <= 54, by(statefip PeriodSIPP) weight(wtfinl)
egen constructionemployedSIPP = wtmean(constructionemp) if age >= 16 & age <= 64 , by(statefip PeriodSIPP) weight(wtfinl)

label var employedlow "Low-Skilled Employment"
label var employedyoung "Young Adult Employment"
label var employedprime "Prime Aged Employment"
label var employedprimeSIPP "Prime Aged Employment"
label var constructionemployedSIPP "Construction Employment"
label var constructionemployed "Construction Employment"


**** Prime-aged employment variations for the SIPP sample period
bysort Treatment PeriodSIPP: eststo: estpost tabstat employedprimeSIPP constructionemployedSIPP [aw = wtfinl], ///
	columns(statistics) statistics(mean sd)
esttab using "${resultsdirectory}\PrimeAgedEmpInCPSForSIPPPeriod.csv", replace main(mean) label nomtitle nolegend nonotes
estimates clear

**** Summary statistics on the severity of the recession and on low-skilled 
**** groups' employment changes.
bysort Treatment PeriodCPS: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction constructionemployed employedprime employedyoung employedlow [aw = wtfinl], ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsCPS.csv", replace main(mean) label nomtitle nolegend nonotes
estimates clear

**** Within-Region Variation in the Recession
bysort regionstring Treatment PeriodCPS: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction constructionemployed employedprime employedyoung employedlow [aw = wtfinl], ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsCPSRegion.csv", replace main(mean) label nonotes
estimates clear

tab regionstring [aw = wtfinl] if skillgroup == 1 & Treatment == 1
tab regionstring [aw = wtfinl] if skillgroup == 1


**** Summary statistics relevant to Zipperer's falsification checks
*** Note that 1 = "placebo treatment" 2 = "placebo control" and 3 = "rest of region-bound-region"
*** (2 = "placebo control" because the summary statistics restrict based on Treatment == 0)
gen placebotreatmentB = 2
replace placebotreatmentB = 1 if statefip == 4 | statefip == 8 | statefip == 12 | statefip == 11 | statefip == 54 | statefip == 10
replace placebotreatmentB = 3 if (division == 8 | division == 5) & placebotreatmentB != 1

gen placebotreatmentA = 2
replace placebotreatmentA = 1 if statefip == 12 | statefip == 54 | statefip == 11 | statefip == 10
replace placebotreatmentA = 3 if region == 3 & placebotreatmentA != 1

bysort placebotreatmentA PeriodCPS: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction [aw = wtfinl] if Treatment == 0 | placebotreatmentA == 3, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsCPSPlaceboReg.csv", replace main(mean) label nonotes
estimates clear

bysort placebotreatmentB PeriodCPS: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction [aw = wtfinl] if Treatment == 0 | placebotreatmentA == 3, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsCPSPlaceboDiv.csv", replace main(mean) label nonotes
estimates clear

bysort placebotreatmentA PeriodSIPP: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction [aw = wtfinl] if Treatment == 0 | placebotreatmentA == 3, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsSIPPPlaceboReg.csv", replace main(mean) label nonotes
estimates clear

bysort placebotreatmentB PeriodSIPP: eststo: estpost tabstat personal_income employment_rate unemployment_rate index construction [aw = wtfinl] if Treatment == 0 | placebotreatmentA == 3, ///
	columns(statistics) statistics(mean sd)

esttab using "${resultsdirectory}\MacroSumStatsSIPPPlaceboDiv.csv", replace main(mean) label nonotes
estimates clear

drop placebotreatmentB placebotreatmentA



*==================================================
***** Beginning of regression analysis section
*==================================================
**** First stage regressions
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1BaseCPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1RegCPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1DivCPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1DivConst0506CPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1Const0506CPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageGroup1Ind0506CPS", replace

reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageYoungBaseCPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageYoungRegCPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageYoungDivCPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageYoungDivConst0506CPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageYoungConst0506CPS", replace
reg mw Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/FirstStageYoungInd0506CPS", replace


*** Employment outcomes with region variable
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegCPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungRegCPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2BaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2RegCPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3BaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3RegCPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleBaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleRegCPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldBaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldRegCPS", replace


*** Employment outcomes with division variable
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2DivCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3DivCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleDivCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldDivCPS", replace

*** Employment outcomes with division variable and construction
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivConst0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2DivConst0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3DivConst0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleDivConst0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldDivConst0506CPS", replace

 
**** Estimates with Spatial Controls and No FL or AZ
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506CPSNoFLAZ", replace
 
**** Estimates with Spatial Controls and Housing Match 01
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506CPSMatch", replace

**** Estimates with Spatial Controls and Housing Match 02
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1RegCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1DivConst0506CPSMatch02", replace


**** Young Adult Sample: Estimates with Spatial Controls and No FL or AZ
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungRegCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivConst0506CPSNoFLAZ", replace

**** Young Adult Sampe: Estimates with Spatial Controls and Housing Match 01
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungRegCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivConst0506CPSMatch", replace

**** Young Adult Sampe: Estimates with Spatial Controls and Housing Match 02
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.region [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungRegCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##i.division i.time##c.constructionshare0506 [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungDivConst0506CPSMatch02", replace




*** Employment outcomes with Construction share variable
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506CPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungConst0506CPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2BaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2Const0506CPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3BaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3Const0506CPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleBaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleConst0506CPS", replace

reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldBaseCPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldConst0506CPS", replace

*** Employment outcomes with set of industry share variables
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungInd0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if skillgroup== 2 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup2Ind0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if skillgroup== 3 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup3Ind0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  [aw = wtfinl] if age >= 22 & age <= 45 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedMiddleInd0506CPS", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506)  [aw = wtfinl] if age >= 46 & age <= 64 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedOldInd0506CPS", replace


**** CPS Estimates with Industry Controls and No FL or AZ
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506CPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if statefip != 12 & statefip != 4 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506CPSNoFLAZ", replace

**** CPS Estimates with Industry Controls and Housing Match 01
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506CPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if ismatched01 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506CPSMatch", replace

**** CPS Estimates with Industry Controls and Housing Match 02
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Const0506CPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if ismatched02 == 1 & skillgroup== 1 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1Ind0506CPSMatch02", replace


**** Young Adult Samples: CPS Estimates with Industry Controls and No FL or AZ
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungConst0506CPSNoFLAZ", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if statefip != 12 & statefip != 4 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungInd0506CPSNoFLAZ", replace

**** Young Adult Samples: CPS Estimates with Industry Controls and Housing Match 01
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungConst0506CPSMatch", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if ismatched01 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungInd0506CPSMatch", replace

**** Young Adult Samples: CPS Estimates with Industry Controls and Housing Match 02
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungBaseCPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##c.constructionshare0506 [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungConst0506CPSMatch02", replace
reg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wtfinl] if ismatched02 == 1 & age <= 21 & sampleframeE == 1, cluster(statefip)
estimates save "${resultsdirectory}/EmployedYoungInd0506CPSMatch02", replace


capture log close
